"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AdIntegrationKind = void 0;
/**
 * The type of ad source:
 * <br/> - `'vast'`: The source is a VAST resource.
 * <br/> - `'vmap'`: The source is a VMAP resource.
 * <br/> - `'adrule'`: The source is a Ad Rule resource.
 *
 * @remarks
 * <br/> - An ad rule is a simplified VMAP alternative only available in the Google IMA integration.
 *
 * @public
 */
/**
 * Describes the source of the ad.
 *
 * @public
 */
/**
 * Describes an ad break request.
 *
 * @public
 */
/**
 * The integration of an ad break, represented by a value from the following list:
 * <br/> - `'csai'`: Default CSAI ad playback.
 * <br/> - `'theo'`: Old naming for `'csai'` - Default ad playback. (Deprecated)
 * <br/> - `'google-ima'`: {@link https://developers.google.com/interactive-media-ads/docs/sdks/html5|Google IMA}.
 * <br/> - `'google-dai'`: {@link https://developers.google.com/ad-manager/dynamic-ad-insertion/sdk/html5 | Google DAI}.
 * <br/> - `'spotx'`: {@link https://developer.spotxchange.com/|SpotX} pre-integrated ad playback.
 * <br/> - `'freewheel'`: {@link https://vi.freewheel.tv/|FreeWheel} pre-integrated ad playback.
 * <br/> - `'theoads'`: [Experimental] - API under development, do not use without consulting THEO Technologies.
 *
 * @remarks
 * <br/> - An empty string defaults to `'theo'`.
 *
 * @public
 */
let AdIntegrationKind = exports.AdIntegrationKind = /*#__PURE__*/function (AdIntegrationKind) {
  AdIntegrationKind["freewheel"] = "freewheel";
  AdIntegrationKind["google_ima"] = "google-ima";
  AdIntegrationKind["google_dai"] = "google-dai";
  AdIntegrationKind["spotx"] = "spotx";
  AdIntegrationKind["csai"] = "csai";
  AdIntegrationKind["theo"] = "theo";
  AdIntegrationKind["theoads"] = "theoads";
  return AdIntegrationKind;
}({});
//# sourceMappingURL=Ads.js.map