"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.THEOplayerView = THEOplayerView;
var _react = _interopRequireWildcard(require("react"));
var _theoplayer = require("theoplayer");
var _THEOplayerWebAdapter = require("./adapter/THEOplayerWebAdapter");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function THEOplayerView(props) {
  const {
    config,
    children
  } = props;
  const player = (0, _react.useRef)(null);
  const adapter = (0, _react.useRef)(null);
  const container = (0, _react.useRef)(null);
  (0, _react.useEffect)(() => {
    // Create player inside container.
    if (container.current) {
      const chromeless = config?.chromeless === true || config?.chromeless === undefined;
      const ads = {
        ...config?.ads,
        googleIma: {
          ...config?.ads?.ima,
          useNativeIma: true,
          language: config?.ui?.language ?? 'en'
        }
      };
      const updatedConfig = {
        ...config,
        allowNativeFullscreen: true,
        ads
      };
      if (chromeless) {
        player.current = new _theoplayer.ChromelessPlayer(container.current, updatedConfig);
      } else {
        player.current = new _theoplayer.Player(container.current, {
          ...updatedConfig,
          ads,
          ui: {
            ...config?.ui,
            fluid: true
          }
        });
      }

      // Adapt native player to react-native player.
      adapter.current = new _THEOplayerWebAdapter.THEOplayerWebAdapter(player.current, config);

      // Expose players for easy access
      // @ts-ignore
      window.player = adapter.current;

      // @ts-ignore
      window.nativePlayer = player;

      // Notify the player is ready
      props.onPlayerReady?.(adapter.current);
    }

    // Clean-up
    return () => {
      // Notify the player will be destroyed.
      const {
        onPlayerDestroy
      } = props;
      if (adapter?.current && onPlayerDestroy) {
        onPlayerDestroy(adapter?.current);
      }
      adapter?.current?.destroy();
    };
  }, [container]);
  const chromeless = config?.chromeless === undefined || config?.chromeless;
  return (
    /*#__PURE__*/
    // Note: display: contents causes an element's children to appear as if they were direct children of the element's parent,
    // ignoring the element itself.
    // It's necessary to make sure we do not interfere with the IMA container
    _react.default.createElement("div", {
      id: 'theoplayer-root-container',
      style: {
        display: 'contents'
      }
    }, /*#__PURE__*/_react.default.createElement("div", {
      ref: container,
      style: styles.container,
      className: chromeless ? 'theoplayer-container' : 'theoplayer-container video-js theoplayer-skin'
    }), children)
  );
}
const styles = {
  // by default stretch the video to cover the container.
  // Override using the 'theoplayer-container' class.
  container: {
    display: 'flex',
    position: 'relative',
    width: '100%',
    height: '100%',
    maxHeight: '100vh',
    maxWidth: '100vw',
    aspectRatio: '16 / 9'
  }
};
//# sourceMappingURL=THEOplayerView.web.js.map