export let TextTrackType = /*#__PURE__*/function (TextTrackType) {
  TextTrackType["cea608"] = "cea608";
  TextTrackType["id3"] = "id3";
  TextTrackType["srt"] = "srt";
  TextTrackType["ttml"] = "ttml";
  TextTrackType["webvtt"] = "webvtt";
  TextTrackType["daterange"] = "daterange";
  TextTrackType["eventstream"] = "eventstream";
  TextTrackType["emsg"] = "emsg";
  return TextTrackType;
}({});
export let TextTrackKind = /*#__PURE__*/function (TextTrackKind) {
  TextTrackKind["captions"] = "captions";
  TextTrackKind["chapters"] = "chapters";
  TextTrackKind["descriptions"] = "descriptions";
  TextTrackKind["metadata"] = "metadata";
  TextTrackKind["subtitles"] = "subtitles";
  TextTrackKind["thumbnails"] = "thumbnails";
  return TextTrackKind;
}({});
export let TextTrackMode = /*#__PURE__*/function (TextTrackMode) {
  TextTrackMode["disabled"] = "disabled";
  TextTrackMode["showing"] = "showing";
  TextTrackMode["hidden"] = "hidden";
  return TextTrackMode;
}({});
/**
 * Retain renderable tracks.
 * https://html.spec.whatwg.org/multipage/embedded-content.html#text-track-showing
 */
export function filterRenderableTracks(textTracks) {
  return textTracks && textTracks.filter(textTrack => textTrack.kind === 'subtitles' || textTrack.kind === 'captions');
}

/**
 * Retain first thumbnail track encountered in the textTracks list.
 */
export function filterThumbnailTracks(textTracks) {
  return textTracks && textTracks.find(isThumbnailTrack);
}

/**
 * Query whether a track is a valid thumbnail track.
 */
export function isThumbnailTrack(textTrack) {
  return !!textTrack && (textTrack.kind === 'thumbnails' || textTrack.kind === 'metadata' && textTrack.label === 'thumbnails');
}
export function hasTextTrackCue(textTrack, cue) {
  return !!(textTrack.cues && cue && textTrack.cues.find(c => cue.uid === c.uid));
}
export function removeTextTrackCue(textTrack, cue) {
  if (textTrack && textTrack.cues && cue && hasTextTrackCue(textTrack, cue)) {
    textTrack.cues = textTrack.cues.filter(c => c.uid !== cue.uid);
  }
}
export function addTextTrackCue(textTrack, cue) {
  if (textTrack && textTrack.cues && cue && !hasTextTrackCue(textTrack, cue)) {
    textTrack.cues.push(cue);
  }
}
export function findTextTrackByUid(textTracks, uid) {
  return textTracks.find(t => t.uid === uid);
}
//# sourceMappingURL=TextTrack.js.map