/**
 * Represents a track of a media resource.
 *
 * @remarks
 * <br/> - A specific track type (e.g. {@link TextTrack}) will always be used.
 *
 * @public
 */

export function hasTrack(trackList, track) {
  return !!(trackList && track && trackList.find(t => t.uid === track.uid));
}
export function removeTrack(trackList, track) {
  return trackList && track ? trackList.filter(t => t.uid !== track.uid) : trackList;
}
export function addTrack(trackList, track) {
  return trackList && track && !hasTrack(trackList, track) ? sortTracks([...trackList, track]) : trackList;
}
export function sortTracks(trackList) {
  return trackList?.sort((t1, t2) => t1.uid - t2.uid) || [];
}
//# sourceMappingURL=Track.js.map