import { BaseEvent } from './BaseEvent';
import { CastEventType, PlayerEventType } from 'react-native-theoplayer';
export class DefaultLoadedMetadataEvent extends BaseEvent {
  constructor(textTracks, audioTracks, videoTracks, duration, selectedTextTrack, selectedVideoTrack, selectedAudioTrack) {
    super(PlayerEventType.LOADED_METADATA);
    this.textTracks = textTracks;
    this.audioTracks = audioTracks;
    this.videoTracks = videoTracks;
    this.duration = duration;
    this.selectedTextTrack = selectedTextTrack;
    this.selectedVideoTrack = selectedVideoTrack;
    this.selectedAudioTrack = selectedAudioTrack;
  }
}
export class DefaultReadyStateChangeEvent extends BaseEvent {
  constructor(readyState) {
    super(PlayerEventType.READYSTATE_CHANGE);
    this.readyState = readyState;
  }
}
export class DefaultPresentationModeChangeEvent extends BaseEvent {
  constructor(presentationMode, previousPresentationMode, context) {
    super(PlayerEventType.PRESENTATIONMODE_CHANGE);
    this.presentationMode = presentationMode;
    this.previousPresentationMode = previousPresentationMode;
    this.context = context;
  }
}
export class DefaultVolumeChangeEvent extends BaseEvent {
  constructor(volume, muted) {
    super(PlayerEventType.VOLUME_CHANGE);
    this.volume = volume;
    this.muted = muted;
  }
}
export class DefaultResizeEvent extends BaseEvent {
  constructor(width, height) {
    super(PlayerEventType.RESIZE);
    this.width = width;
    this.height = height;
  }
}
export class DefaultErrorEvent extends BaseEvent {
  constructor(error) {
    super(PlayerEventType.ERROR);
    this.error = error;
  }
}
export class DefaultProgressEvent extends BaseEvent {
  constructor(seekable, buffered) {
    super(PlayerEventType.PROGRESS);
    this.seekable = seekable;
    this.buffered = buffered;
  }
}
export class DefaultTimeupdateEvent extends BaseEvent {
  constructor(currentTime, currentProgramDateTime) {
    super(PlayerEventType.TIME_UPDATE);
    this.currentTime = currentTime;
    this.currentProgramDateTime = currentProgramDateTime;
  }
}
export class DefaultDurationChangeEvent extends BaseEvent {
  constructor(duration) {
    super(PlayerEventType.DURATION_CHANGE);
    this.duration = duration;
  }
}
export class DefaultRateChangeEvent extends BaseEvent {
  constructor(playbackRate) {
    super(PlayerEventType.RATE_CHANGE);
    this.playbackRate = playbackRate;
  }
}
export class DefaultSegmentNotFoundEvent extends BaseEvent {
  constructor(segmentStartTime, error, retryCount) {
    super(PlayerEventType.SEGMENT_NOT_FOUND);
    this.segmentStartTime = segmentStartTime;
    this.error = error;
    this.retryCount = retryCount;
  }
}
export class DefaultTextTrackListEvent extends BaseEvent {
  constructor(subType, track) {
    super(PlayerEventType.TEXT_TRACK_LIST);
    this.subType = subType;
    this.track = track;
  }
}
export class DefaultTextTrackEvent extends BaseEvent {
  constructor(subType, trackUid, cue) {
    super(PlayerEventType.TEXT_TRACK);
    this.subType = subType;
    this.trackUid = trackUid;
    this.cue = cue;
  }
}
export class DefaultMediaTrackListEvent extends BaseEvent {
  constructor(subType, trackType, track) {
    super(PlayerEventType.MEDIA_TRACK_LIST);
    this.subType = subType;
    this.trackType = trackType;
    this.track = track;
  }
}
export class DefaultMediaTrackEvent extends BaseEvent {
  constructor(subType, trackType, trackUid, qualities) {
    super(PlayerEventType.MEDIA_TRACK);
    this.subType = subType;
    this.trackType = trackType;
    this.trackUid = trackUid;
    this.qualities = qualities;
  }
}
export class DefaultAdEvent extends BaseEvent {
  constructor(subType, ad) {
    super(PlayerEventType.AD_EVENT);
    this.subType = subType;
    this.ad = ad;
  }
}
export class DefaultChromecastChangeEvent extends BaseEvent {
  constructor(state) {
    super(PlayerEventType.CAST_EVENT);
    this.state = state;
    this.subType = CastEventType.CHROMECAST_STATE_CHANGE;
  }
}
export class DefaultAirplayStateChangeEvent extends BaseEvent {
  constructor(state) {
    super(PlayerEventType.CAST_EVENT);
    this.state = state;
    this.subType = CastEventType.AIRPLAY_STATE_CHANGE;
  }
}
export class DefaultChromecastErrorEvent extends BaseEvent {
  constructor(error) {
    super(PlayerEventType.CAST_EVENT);
    this.error = error;
    this.subType = CastEventType.CHROMECAST_ERROR;
  }
}
//# sourceMappingURL=PlayerEvents.js.map