import { BaseEvent } from './BaseEvent';
import { Ad, AdBreak, AdEvent, AdEventType, AirplayStateChangeEvent, CastEventType, CastState, ChromecastChangeEvent, ChromecastError, ChromecastErrorEvent, DurationChangeEvent, ErrorEvent, LoadedMetadataEvent, MediaTrack, MediaTrackEvent, MediaTrackEventType, MediaTrackListEvent, MediaTrackType, PlayerError, PlayerEventType, PresentationMode, PresentationModeChangeContext, PresentationModeChangeEvent, ProgressEvent, Quality, RateChangeEvent, ReadyStateChangeEvent, ResizeEvent, SegmentNotFoundEvent, TextTrack, TextTrackCue, TextTrackEvent, TextTrackEventType, TextTrackListEvent, TimeRange, TimeUpdateEvent, TrackListEventType, VolumeChangeEvent } from 'react-native-theoplayer';
export declare class DefaultLoadedMetadataEvent extends BaseEvent<PlayerEventType.LOADED_METADATA> implements LoadedMetadataEvent {
    textTracks: TextTrack[];
    audioTracks: MediaTrack[];
    videoTracks: MediaTrack[];
    duration: number;
    selectedTextTrack: number | undefined;
    selectedVideoTrack: number | undefined;
    selectedAudioTrack: number | undefined;
    constructor(textTracks: TextTrack[], audioTracks: MediaTrack[], videoTracks: MediaTrack[], duration: number, selectedTextTrack: number | undefined, selectedVideoTrack: number | undefined, selectedAudioTrack: number | undefined);
}
export declare class DefaultReadyStateChangeEvent extends BaseEvent<PlayerEventType.READYSTATE_CHANGE> implements ReadyStateChangeEvent {
    readyState: number;
    constructor(readyState: number);
}
export declare class DefaultPresentationModeChangeEvent extends BaseEvent<PlayerEventType.PRESENTATIONMODE_CHANGE> implements PresentationModeChangeEvent {
    presentationMode: PresentationMode;
    previousPresentationMode: PresentationMode;
    context?: PresentationModeChangeContext | undefined;
    constructor(presentationMode: PresentationMode, previousPresentationMode: PresentationMode, context?: PresentationModeChangeContext | undefined);
}
export declare class DefaultVolumeChangeEvent extends BaseEvent<PlayerEventType.VOLUME_CHANGE> implements VolumeChangeEvent {
    volume: number;
    muted: boolean;
    constructor(volume: number, muted: boolean);
}
export declare class DefaultResizeEvent extends BaseEvent<PlayerEventType.RESIZE> implements ResizeEvent {
    width: number;
    height: number;
    constructor(width: number, height: number);
}
export declare class DefaultErrorEvent extends BaseEvent<PlayerEventType.ERROR> implements ErrorEvent {
    error: PlayerError;
    constructor(error: PlayerError);
}
export declare class DefaultProgressEvent extends BaseEvent<PlayerEventType.PROGRESS> implements ProgressEvent {
    seekable: TimeRange[];
    buffered: TimeRange[];
    constructor(seekable: TimeRange[], buffered: TimeRange[]);
}
export declare class DefaultTimeupdateEvent extends BaseEvent<PlayerEventType.TIME_UPDATE> implements TimeUpdateEvent {
    currentTime: number;
    currentProgramDateTime?: number | undefined;
    constructor(currentTime: number, currentProgramDateTime?: number | undefined);
}
export declare class DefaultDurationChangeEvent extends BaseEvent<PlayerEventType.DURATION_CHANGE> implements DurationChangeEvent {
    duration: number;
    constructor(duration: number);
}
export declare class DefaultRateChangeEvent extends BaseEvent<PlayerEventType.RATE_CHANGE> implements RateChangeEvent {
    playbackRate: number;
    constructor(playbackRate: number);
}
export declare class DefaultSegmentNotFoundEvent extends BaseEvent<PlayerEventType.SEGMENT_NOT_FOUND> implements SegmentNotFoundEvent {
    readonly segmentStartTime: number;
    error: string;
    retryCount: number;
    constructor(segmentStartTime: number, error: string, retryCount: number);
}
export declare class DefaultTextTrackListEvent extends BaseEvent<PlayerEventType.TEXT_TRACK_LIST> implements TextTrackListEvent {
    subType: TrackListEventType;
    track: TextTrack;
    constructor(subType: TrackListEventType, track: TextTrack);
}
export declare class DefaultTextTrackEvent extends BaseEvent<PlayerEventType.TEXT_TRACK> implements TextTrackEvent {
    subType: TextTrackEventType;
    trackUid: number;
    cue: TextTrackCue;
    constructor(subType: TextTrackEventType, trackUid: number, cue: TextTrackCue);
}
export declare class DefaultMediaTrackListEvent extends BaseEvent<PlayerEventType.MEDIA_TRACK_LIST> implements MediaTrackListEvent {
    subType: TrackListEventType;
    trackType: MediaTrackType;
    track: MediaTrack;
    constructor(subType: TrackListEventType, trackType: MediaTrackType, track: MediaTrack);
}
export declare class DefaultMediaTrackEvent extends BaseEvent<PlayerEventType.MEDIA_TRACK> implements MediaTrackEvent {
    subType: MediaTrackEventType;
    trackType: MediaTrackType;
    trackUid: number;
    qualities?: Quality | Quality[] | undefined;
    constructor(subType: MediaTrackEventType, trackType: MediaTrackType, trackUid: number, qualities?: Quality | Quality[] | undefined);
}
export declare class DefaultAdEvent extends BaseEvent<PlayerEventType.AD_EVENT> implements AdEvent {
    subType: AdEventType;
    ad: Ad | AdBreak;
    constructor(subType: AdEventType, ad: Ad | AdBreak);
}
export declare class DefaultChromecastChangeEvent extends BaseEvent<PlayerEventType.CAST_EVENT> implements ChromecastChangeEvent {
    state: CastState;
    readonly subType: CastEventType.CHROMECAST_STATE_CHANGE;
    constructor(state: CastState);
}
export declare class DefaultAirplayStateChangeEvent extends BaseEvent<PlayerEventType.CAST_EVENT> implements AirplayStateChangeEvent {
    state: CastState;
    readonly subType: CastEventType.AIRPLAY_STATE_CHANGE;
    constructor(state: CastState);
}
export declare class DefaultChromecastErrorEvent extends BaseEvent<PlayerEventType.CAST_EVENT> implements ChromecastErrorEvent {
    error: ChromecastError;
    readonly subType: CastEventType.CHROMECAST_ERROR;
    constructor(error: ChromecastError);
}
//# sourceMappingURL=PlayerEvents.d.ts.map