import type { MediaTrack, Quality, TextTrack, TextTrackCue } from 'react-native-theoplayer';
import { MediaTrackEventType, MediaTrackType, TextTrackEventType, TrackListEventType } from 'react-native-theoplayer';
export declare enum NativeTrackListEventType {
    /**
     * Dispatched when track has been added to the track list.
     */
    AddTrack = 0,
    /**
     * Dispatched when track has been removed from the track list.
     */
    RemoveTrack = 1,
    /**
     * Fired when a track has been changed.
     */
    ChangeTrack = 2
}
export interface NativeTrackListEvent {
    /**
     * The type of track list event.
     */
    readonly type: NativeTrackListEventType;
}
export interface NativeTextTrackListEvent extends NativeTrackListEvent {
    /**
     * The relevant text track.
     */
    readonly track: TextTrack;
}
export declare enum NativeTextTrackEventType {
    /**
     * Dispatched when cue has been added to the text track.
     */
    AddCue = 0,
    /**
     * Dispatched when cue has been removed from the text track.
     */
    RemoveCue = 1,
    /**
     * Dispatched when a cue of the track enters.
     */
    EnterCue = 2,
    /**
     * Dispatched when a cue of the track exits.
     */
    ExitCue = 3
}
export interface NativeTextTrackEvent {
    /**
     * The type of text track event.
     */
    readonly type: NativeTextTrackEventType;
    /**
     * The text track's uid to which this cue belongs.
     */
    readonly trackUid: number;
    /**
     * The text track's cue.
     */
    readonly cue: TextTrackCue;
}
export declare enum NativeMediaTrackType {
    Audio = 0,
    Video = 1
}
export interface NativeMediaTrackListEvent extends NativeTrackListEvent {
    /**
     * The relevant media track type, either {@link NativeMediaTrackType.Audio} or {@link NativeMediaTrackType.Video}.
     */
    readonly trackType: NativeMediaTrackType;
    /**
     * The relevant media track.
     */
    readonly track: MediaTrack;
}
export declare enum NativeMediaTrackEventType {
    /**
     * Dispatched when the media track's active quality changes.
     */
    ActiveQualityChanged = 0
}
export interface NativeMediaTrackEvent {
    /**
     * The type of media track event.
     */
    readonly type: NativeMediaTrackEventType;
    /**
     * The media track's type to which event belongs, either {@link MediaTrackType.Audio} or {@link MediaTrackType.Video}.
     */
    readonly trackType: NativeMediaTrackType;
    /**
     * The media track's uid to which event belongs.
     */
    readonly trackUid: number;
    /**
     * The affected media track's qualities.
     */
    readonly qualities?: Quality | Quality[];
}
export declare function toTrackListEventType(type: NativeTrackListEventType): TrackListEventType;
export declare function toTextTrackEventType(type: NativeTextTrackEventType): TextTrackEventType;
export declare function toMediaTrackType(type: NativeMediaTrackType): MediaTrackType;
export declare function toMediaTrackTypeEventType(type: NativeMediaTrackEventType): MediaTrackEventType;
//# sourceMappingURL=NativeTrackEvent.d.ts.map